import type { Either, ErrorResolver } from '@lokalise/node-core';
import type { QueueConsumer, NewQueueOptions, ExistingQueueOptions, MonoSchemaQueueOptions } from '@message-queue-toolkit/core';
import type { Message } from 'amqplib';
import type { ZodSchema } from 'zod';
import type { AMQPConsumerDependencies, CreateAMQPQueueOptions } from './AbstractAmqpService';
import { AbstractAmqpService } from './AbstractAmqpService';
export type AMQPLocatorType = {
    queueName: string;
};
export type NewAMQPConsumerOptions = NewQueueOptions<CreateAMQPQueueOptions>;
export type ExistingAMQPConsumerOptions = ExistingQueueOptions<AMQPLocatorType>;
export declare abstract class AbstractAmqpConsumer<MessagePayloadType extends object> extends AbstractAmqpService<MessagePayloadType, AMQPConsumerDependencies> implements QueueConsumer {
    private readonly transactionObservabilityManager?;
    protected readonly errorResolver: ErrorResolver;
    private readonly messageSchema;
    private readonly schemaEither;
    constructor(dependencies: AMQPConsumerDependencies, options: (NewAMQPConsumerOptions & MonoSchemaQueueOptions<MessagePayloadType>) | (ExistingAMQPConsumerOptions & MonoSchemaQueueOptions<MessagePayloadType>));
    abstract processMessage(messagePayload: MessagePayloadType): Promise<Either<'retryLater', 'success'>>;
    private deserializeMessage;
    start(): Promise<void>;
    protected resolveMessage(message: Message): Either<import("@message-queue-toolkit/core").MessageInvalidFormatError | import("@message-queue-toolkit/core").MessageValidationError, unknown>;
    protected resolveSchema(_message: MessagePayloadType): Either<Error, ZodSchema<MessagePayloadType, import("zod").ZodTypeDef, MessagePayloadType>>;
}
